@@ -383,9 +383,7 @@ def search(table: str):
 @cache
 @app.route("/journal/<int:id_>/")
 def journal(id_: int):
-    jrnl, prev_id, next_id = load_item(journals_table, id_)
-
-    if jrnl is None:
+    if (jrnl := load_item(journals_table, id_)) is None:
         return error(
             f"Journal not found.<br>{button(f'https://www.furaffinity.net/journal/{id_}', 'Open on Fur Affinity')}",
             404
@@ -395,8 +393,8 @@ def journal(id_: int):
         "journal.html",
         title=f"{app.name} · {jrnl['TITLE']} by {jrnl['AUTHOR']}",
         journal=jrnl,
-        prev=prev_id,
-        next=next_id
+        prev=(prev_next := load_prev_next(journals_table, id_))[0],
+        next=prev_next[1]
     )
 
 
@@ -404,9 +402,7 @@ def journal(id_: int):
 @app.route("/journal/<int:id_>/zip/")
 @app.route("/journal/<int:id_>/zip/<filename>")
 def journal_zip(id_: int, filename: str = None):
-    jrn, _, _ = load_item(journals_table, id_)
-
-    if jrn is None:
+    if (jrn := load_item(journals_table, id_)) is None:
         return abort(404)
 
     f_obj: BytesIO = BytesIO()
@@ -493,12 +489,14 @@ def submission_zip(id_: int, filename: str = None):
     if (sub := load_item(submissions_table, id_, False)) is None:
         return abort(404)
 
-    _, sub_filesaved, sub_file, _ = load_submission_file(id_)
+    _, sub_filesaved, sub_file, sub_thumb = load_submission_file(id_)
     f_obj: BytesIO = BytesIO()
 
     with ZipFile(f_obj, "w") as z:
         if sub_filesaved >= 10 and isfile(sub_file):
             z.writestr(basename(sub_file), open(sub_file, "rb").read())
+        if sub_filesaved % 10 == 1 and isfile(sub_thumb):
+            z.writestr(basename(sub_thumb), open(sub_thumb, "rb").read())
         z.writestr("description.html", sub["DESCRIPTION"].encode())
         z.writestr("metadata.json", json_dumps({k: v for k, v in sub.items() if k != "DESCRIPTION"}).encode())
 
